==> grilo-plugins_0.2.17.orig.tar.xz: grilo-plugins-0.2.17/src/magnatune/grl-magnatune.h <==
/*
 * Copyright (C) 2013 Victor Toso.
 *
 * Contact: Victor Toso <me@victortoso.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef _GRL_MAGNATUNE_SOURCE_H_
#define _GRL_MAGNATUNE_SOURCE_H_

#include <grilo.h>

#define GRL_MAGNATUNE_SOURCE_TYPE                        \
  (grl_magnatune_source_get_type())

#define GRL_MAGNATUNE_SOURCE(obj)                        \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),                     \
                              GRL_MAGNATUNE_SOURCE_TYPE, \
                              GrlMagnatuneSource))

#define GRL_MAGNATUNE_SOURCE_CLASS(klass)                \
  (G_TYPE_CHECK_CLASS_CAST((klass),                      \
                           GRL_MAGNATUNE_SOURCE_TYPE,    \
                           GrlMagnatuneSourceClass))

#define GRL_IS_MAGNATUNE_SOURCE_CLASS(klass)             \
  (G_TYPE_CHECK_CLASS_TYPE((klass),                      \
                           GRL_MAGNATUNE_SOURCE_TYPE))

#define GRL_MAGNATUNE_SOURCE_GET_CLASS(obj)              \
  (G_TYPE_INSTANCE_GET_CLASS((obj),                      \
                              GRL_MAGNATUNE_SOURCE_TYPE, \
                              GrlMagnatuneSourceClass))

typedef struct _GrlMagnatunePrivate GrlMagnatunePrivate;
typedef struct _GrlMagnatuneSource  GrlMagnatuneSource;

struct _GrlMagnatuneSource {
  GrlSource parent;
  GrlMagnatunePrivate *priv;
};

typedef struct _GrlMagnatuneSourceClass GrlMagnatuneSourceClass;

struct _GrlMagnatuneSourceClass {
  GrlSourceClass parent_class;
};

GType grl_magnatune_source_get_type(void);

#endif /* _GRL_MAGNATUNE_SOURCE_H_ */

==> grilo-plugins-0.3.15.tar.xz: grilo-plugins-0.3.15/src/magnatune/grl-magnatune.h <==
/*
 * Copyright (C) 2013 Victor Toso.
 *
 * Contact: Victor Toso <me@victortoso.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef _GRL_MAGNATUNE_SOURCE_H_
#define _GRL_MAGNATUNE_SOURCE_H_

#include <grilo.h>

#define GRL_MAGNATUNE_SOURCE_TYPE                        \
  (grl_magnatune_source_get_type())

#define GRL_MAGNATUNE_SOURCE(obj)                        \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),                     \
                              GRL_MAGNATUNE_SOURCE_TYPE, \
                              GrlMagnatuneSource))

#define GRL_MAGNATUNE_SOURCE_CLASS(klass)                \
  (G_TYPE_CHECK_CLASS_CAST((klass),                      \
                           GRL_MAGNATUNE_SOURCE_TYPE,    \
                           GrlMagnatuneSourceClass))

#define GRL_IS_MAGNATUNE_SOURCE_CLASS(klass)             \
  (G_TYPE_CHECK_CLASS_TYPE((klass),                      \
                           GRL_MAGNATUNE_SOURCE_TYPE))

#define GRL_MAGNATUNE_SOURCE_GET_CLASS(obj)              \
  (G_TYPE_INSTANCE_GET_CLASS((obj),                      \
                              GRL_MAGNATUNE_SOURCE_TYPE, \
                              GrlMagnatuneSourceClass))

typedef struct _GrlMagnatunePrivate GrlMagnatuneSourcePrivate;
typedef struct _GrlMagnatuneSource  GrlMagnatuneSource;

struct _GrlMagnatuneSource {
  GrlSource parent;
  GrlMagnatuneSourcePrivate *priv;
};

typedef struct _GrlMagnatuneSourceClass GrlMagnatuneSourceClass;

struct _GrlMagnatuneSourceClass {
  GrlSourceClass parent_class;
};

GType grl_magnatune_source_get_type(void);

#endif /* _GRL_MAGNATUNE_SOURCE_H_ */
